pydeseq2.dds.DeseqDataSet
=========================

.. currentmodule:: pydeseq2.dds

.. autoclass:: pydeseq2.dds.DeseqDataSet

    .. rubric:: Methods

    .. autosummary::

        ~DeseqDataSet.calculate_cooks
        ~DeseqDataSet.cond
        ~DeseqDataSet.deseq2
        ~DeseqDataSet.fit_LFC
        ~DeseqDataSet.fit_MAP_dispersions
        ~DeseqDataSet.fit_dispersion_prior
        ~DeseqDataSet.fit_dispersion_trend
        ~DeseqDataSet.fit_genewise_dispersions
        ~DeseqDataSet.fit_size_factors
        ~DeseqDataSet.plot_dispersions
        ~DeseqDataSet.refit
        ~DeseqDataSet.to_picklable_anndata
        ~DeseqDataSet.vst
